from datetime import datetime
import sys
import requests
import urllib.parse
import csv
import json
import time

host = "api.mobygames.com"
key  = urllib.parse.quote_plus("API KEY REDACTED")

if len(sys.argv) < 3:
    print("This script takes in a file containing a JSON array of game id's and creates a CSV \
        of game information from the Moby Games API/n/nUsage: moby_ids_to_csv.py input.json output.csv")
else:
    with open(sys.argv[1], 'r') as json_file:
        game_ids = json.load(json_file)
        with open(sys.argv[2], 'w', newline='') as csvfile:
            fieldnames = ['game_id', 'title', 'description', 'moby_url', 'sample_screenshots',
                'num_votes', 'genres', 'platforms', 'moby_score', 'official_url', 'sample_cover', 'first_release_any_platform']
            writer = csv.DictWriter(csvfile, fieldnames=fieldnames)
            writer.writeheader()
            for game_id in game_ids:
                path = "/v1/games/{}".format(game_id)
                url = "https://{}{}?api_key={}".format(host, path, key)
                print("Requesting {}...".format(url))
                r = requests.get(url)
                if r.status_code == 200:
                    game = r.json()
                    earliest_release = datetime.strptime("2121-12-31", "%Y-%m-%d")
                    for platform in game['platforms']:
                        if len(platform['first_release_date']) == 4:
                            release_date = datetime.strptime(platform['first_release_date'], "%Y")
                        elif len(platform['first_release_date']) == 7:
                            release_date = datetime.strptime(platform['first_release_date'], "%Y-%m")
                        else:
                            release_date = datetime.strptime(platform['first_release_date'], "%Y-%m-%d")
                        if release_date < earliest_release:
                            earliest_release = release_date
                            game['first_release_any_platform'] = platform['first_release_date']

                    writer.writerow(game)
                else:
                    print("Request to {} failed!\nReceived {}:\n{}".format(url, r.status_code, r.text))

                time.sleep(1) # Throttle requests to avoid rate limiting
            
            writer.writerow({'game_id':0}) # Final row lets us know the operation completed.
