from datetime import datetime
import sys
import requests
import urllib.parse
import csv
import json
import time

host = "api.mobygames.com"
key  = urllib.parse.quote_plus("API KEY REDACTED")
limit = 100
ignored_genres = [76, 187, 177]
release_threshold = datetime.strptime("{}-12-31".format(sys.argv[2]), "%Y-%m-%d")

if len(sys.argv) < 3:
    print("This script compiles a list of every US release of a given platform and creates a CSV \
        of game information from the Moby Games API/n/nUsage: platform_to_csv.py platform-id year-threshold output.csv")
else:
    with open(sys.argv[3], 'w', newline='') as csvfile:
        fieldnames = ['game_id', 'title', 'description', 'moby_url', 'sample_screenshots',
            'num_votes', 'genres', 'platforms', 'moby_score', 'official_url', 'sample_cover', 'this_platform_first_release_date', 'this_platform_releases']
        writer = csv.DictWriter(csvfile, fieldnames=fieldnames)
        writer.writeheader()
        games = []
        offset = 0
        while len(games) > 0 or offset == 0:
            path = "/v1/games"
            url = "https://{}{}?limit={}&offset={}&platform={}&api_key={}".format(host, path, limit, offset, sys.argv[1], key)
            print("Requesting {}...".format(url))
            r = requests.get(url)
            if r.status_code == 200:
                games = r.json()['games']
                offset += len(games)
                for game in games:
                    ignore = False
                    for genre in game['genres']:
                        if genre['genre_id'] in ignored_genres:
                            ignore = True                       
                            break

                    if not ignore:
                        for platform in game['platforms']:
                            if int(platform['platform_id']) == int(sys.argv[1]):
                                game['this_platform_first_release_date'] = platform['first_release_date']
                        
                        time.sleep(1) # Throttle requests to avoid rate limiting
                        path = "/v1/games/{}/platforms/{}".format(game['game_id'], sys.argv[1])
                        url = "https://{}{}?api_key={}".format(host, path, key)
                        print("Requesting {}...".format(url))
                        r = requests.get(url)
                        if r.status_code == 200:
                            game['this_platform_releases'] = r.json()['releases']
                            for release in r.json()['releases']:
                                if len(release['release_date']) == 4:
                                    release_date = datetime.strptime(release['release_date'], "%Y")
                                elif len(release['release_date']) == 7:
                                    release_date = datetime.strptime(release['release_date'], "%Y-%m")
                                else:
                                    release_date = datetime.strptime(release['release_date'], "%Y-%m-%d")
                                if "United States" in release['countries'] and release_date < release_threshold:
                                    writer.writerow(game)
                                    break
                        else:
                            print("Request to {} failed!\nReceived {}:\n{}".format(url, r.status_code, r.text))
            else:
                print("Request to {} failed!\nReceived {}:\n{}".format(url, r.status_code, r.text))

            time.sleep(1) # Throttle requests to avoid rate limiting
            
        writer.writerow({'game_id':0}) # Final row lets us know the operation completed.
